@@ -1,6 +1,5 @@
-import tensorflow as tf
 from keras import layers
-from keras.utils.generic_utils import register_keras_serializable
+from keras.saving.object_registration import register_keras_serializable
 from keras.utils.tf_utils import shape_type_conversion
 from tfswin.norm import LayerNorm
 
