@@ -1,13 +1,12 @@
 import tensorflow as tf
 from keras import layers
+from keras.saving.object_registration import register_keras_serializable
 from keras.utils.control_flow_util import smart_cond
-from keras.utils.generic_utils import register_keras_serializable
 from keras.utils.tf_utils import shape_type_conversion
 from tfswin.drop import DropPath
 from tfswin.mlp import MLP
 from tfswin.norm import LayerNorm
 from tfswin.winatt import WindowAttention
-from tfswin.window import window_partition, window_reverse
 
 
 @register_keras_serializable(package='TFSwin')
@@ -55,8 +54,6 @@ class SwinBlock(layers.Layer):
         inputs, shift_size, window_size, relative_index, attention_mask = inputs
         height, width = tf.unstack(tf.shape(inputs)[1:3])
 
-        with_shift = tf.greater(shift_size, 0)
-
         if self.swin_v2:
             outputs = inputs
         else:
@@ -66,22 +63,17 @@ class SwinBlock(layers.Layer):
         w_pad = (window_size - width % window_size) % window_size
         paddings = [[0, 0], [0, h_pad], [0, w_pad], [0, 0]]
         outputs = tf.pad(outputs, paddings)
-        padded_height, padded_width = height + h_pad, width + w_pad
 
         # Cyclic shift
+        with_shift = shift_size > 0
         outputs = smart_cond(
             with_shift,
             lambda: tf.roll(outputs, [-shift_size, -shift_size], [1, 2]),
-            lambda: tf.identity(outputs))
-
-        # Partition windows
-        outputs = window_partition(outputs, padded_height, padded_width, window_size, self.compute_dtype)
+            lambda: tf.identity(outputs)
+        )
 
         # W-MSA/SW-MSA
-        outputs = self.attn([outputs, window_size, relative_index, attention_mask, with_shift])
-
-        # Merge windows
-        outputs = window_reverse(outputs, padded_height, padded_width, window_size, self.compute_dtype)
+        outputs = self.attn([outputs, window_size, relative_index, attention_mask])
 
         # Reverse cyclic shift
         outputs = smart_cond(
@@ -90,7 +82,7 @@ class SwinBlock(layers.Layer):
             lambda: tf.identity(outputs)
         )
 
-        outputs = outputs[:, :height, :width, ...]
+        outputs = outputs[:, :height, :width]
 
         # FFN
         if self.swin_v2:
