@@ -1,25 +1,25 @@
 import tensorflow as tf
-from keras import keras_parameterized, testing_utils
+from keras.testing_infra import test_combinations, test_utils
 from tfswin.embed import PatchEmbedding
 
 
-@keras_parameterized.run_all_keras_modes
-class TestPatchEmbedding(keras_parameterized.TestCase):
+@test_combinations.run_all_keras_modes
+class TestPatchEmbedding(test_combinations.TestCase):
     def test_layer(self):
-        testing_utils.layer_test(
+        test_utils.layer_test(
             PatchEmbedding,
             kwargs={'patch_size': 4, 'embed_dim': 2, 'normalize': False},
             input_shape=[2, 12, 12, 3],
             input_dtype='float32',
-            expected_output_shape=[None, 9, 2],
+            expected_output_shape=[None, 3, 3, 2],
             expected_output_dtype='float32'
         )
-        testing_utils.layer_test(
+        test_utils.layer_test(
             PatchEmbedding,
             kwargs={'patch_size': 3, 'embed_dim': 2, 'normalize': True},
             input_shape=[2, 12, 12, 3],
             input_dtype='float32',
-            expected_output_shape=[None, 16, 2],
+            expected_output_shape=[None, 4, 4, 2],
             expected_output_dtype='float32'
         )
 
